"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const types_1 = require("../../types");
const token_math_1 = require("@melonproject/token-math");
const normalizeOrder = (options, type, [price, volume, timestamp]) => {
    const oid = Buffer.from(`${types_1.Exchange.KRAKEN}:${price}:${volume}:${timestamp}`).toString('base64');
    const trade = token_math_1.createPrice(token_math_1.createQuantity(options.pair.base, volume), token_math_1.createQuantity(options.pair.quote, price * volume));
    return {
        id: oid,
        exchange: types_1.Exchange.KRAKEN,
        type,
        trade,
    };
};
const getHttpUrl = (options) => {
    const base = options.pair.base.symbol;
    const quote = options.pair.quote.symbol;
    switch (options.network) {
        case types_1.Network.MAINNET:
            return `https://api.kraken.com/0/public/Depth?pair=${base}${quote}`;
        default:
            throw new Error('Kraken only supports the MAINNET network.');
    }
};
exports.fetch = (options) => __awaiter(this, void 0, void 0, function* () {
    const url = getHttpUrl(options);
    const response = yield axios_1.default
        .get(url)
        .then(value => value.data);
    if (response.error && response.error.length) {
        throw new Error(response.error.join(''));
    }
    const result = response.result;
    const base = options.pair.base.symbol;
    const quote = options.pair.quote.symbol;
    const key = `X${base}X${quote}`;
    const orderbook = (result && result[key]) || {
        asks: [],
        bids: [],
    };
    const asks = orderbook.asks.map(order => normalizeOrder(options, types_1.OrderType.ASK, order));
    const bids = orderbook.bids.map(order => normalizeOrder(options, types_1.OrderType.BID, order));
    return [].concat(asks, bids);
});
